@@ -9,7 +9,7 @@
 from argparse import ArgumentParser
 
 
-__version__ = "2.2.1"
+__version__ = "2.4.0"
 # fmt: off
 leetscraper_logo=(
 f"""
@@ -33,10 +33,7 @@ def main():
         add_help=True,
     )
     parser.add_argument(
-        "-v",
-        "--version",
-        help="Print out leetscraper version",
-        action="store_true",
+        "-v", "--version", help="Print out leetscraper version", action="store_true"
     )
 
     args = parser.parse_args()
@@ -44,8 +41,8 @@ def main():
     if args.version:
         print(f"leetscraper v{__version__}")
         return
-    else:
-        print("cli not implemented yet!")
+
+    print("cli not implemented yet!")
 
 
 if __name__ == "__main__":
