@@ -4,8 +4,8 @@
 
 """This module contains the Codechef class and its methods.
 
-Initialisation of the class will set attributes required for most of the
-class methods. Some Leetscraper attributes will be required.
+Initialisation of the class will set attributes required for most of the class methods. Some
+Leetscraper attributes will be required.
 """
 
 from json import loads
@@ -14,16 +14,16 @@ from typing import List, Optional
 
 from urllib3 import PoolManager
 
+from ..cli import __version__
 from ..logger import log_message
+from ..utils import header_constructor
 
 
 class Codechef:
-    """This class contains the methods required to scrape problems for
-    codechef.com."""
+    """This class contains the methods required to scrape problems for codechef.com."""
 
     def __init__(self):
-        """These are the attributes specific to URLs and HTML tags for
-        codechef.com."""
+        """These are the attributes specific to URLs and HTML tags for codechef.com."""
         self.website_name = "codechef.com"
         # Difficulty ratings based on
         # https://blog.codechef.com/2022/02/25/exciting-updates-for-february-2022/
@@ -39,11 +39,10 @@ class Codechef:
         }
         self.api_url = "https://www.codechef.com/api/list/problems/"
         self.base_url = "https://www.codechef.com/problems/"
-        # TODO: Handle multiple HTML tags needed for the problems that
-        # currently fail?
+        # TODO: Handle multiple HTML tags needed for the problems that currently fail?
         self.problem_description = {"class": "problem-statement"}
         self.file_split = "-"
-        self.need_headers = True
+        self.header = header_constructor(__version__)
 
     def get_problems(
         self, http: PoolManager, scraped_problems: List[str], scrape_limit: int
@@ -52,10 +51,8 @@ class Codechef:
         try:
             get_problems: list = []
             headers: dict = {}
-            headers["User-Agent"] = self.headers
-            request = http.request(
-                "GET", self.api_url + "?limit=99999", headers=headers
-            )
+            headers["User-Agent"] = self.header
+            request = http.request("GET", self.api_url, headers=headers)
             data = loads(request.data.decode("utf-8"))
             for problem in data["data"]:
                 if problem["code"] not in scraped_problems:
@@ -65,27 +62,22 @@ class Codechef:
         except Exception as error:
             log_message(
                 "warning",
-                "Failed to get problems for %s. Error: %s",
+                "Failed to get %s problems for %s. Only recieved %s problems! Error: %s",
+                scrape_limit if scrape_limit > 0 else "all",
                 self.website_name,
+                len(get_problems),
                 error,
             )
         return get_problems
 
-    def filter_problem(
-        self,
-        soup: str,
-        problem: List[str],
-    ) -> tuple:
-        """Filters the soup html down to the problem description using HTML
-        tags.
+    def filter_problem(self, soup: str, problem: List[str]) -> tuple:
+        """Filters the soup html down to the problem description using HTML tags.
 
-        Sets the problem_name, and problem_difficulty if needed. If an
-        Error happens, it will return the error message instead.
+        Sets the problem_name, and problem_difficulty if needed. If an Error happens, it will return
+        the error message instead.
         """
         try:
-            filter_problem = (
-                soup.find("div", self.problem_description).get_text().strip()
-            )
+            filter_problem = soup.find("div", self.problem_description).get_text().strip()
             problem_description = filter_problem.split("Author:")[0]
             get_name = (
                 str(soup.find("aside", {"class": "breadcrumbs"}))
@@ -94,9 +86,7 @@ class Codechef:
                 .strip()
                 .replace(" ", "-")
             )
-            get_difficulty = filter_problem.split("Date Added:")[0].split(
-                "Difficulty Rating:"
-            )[1]
+            get_difficulty = filter_problem.split("Date Added:")[0].split("Difficulty Rating:")[1]
             problem_name = sub("[^A-Za-z0-9-]+", "", get_name)
             problem_name = problem[0] + f"-{problem_name}"
             difficulty = sub("[^-0-9]+", "", get_difficulty)
